v1alpha

package
v0.0.13-alpha Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 20, 2020 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type LimePlugin

type LimePlugin interface {
	Name() string
	Description() string
	Version() *common.Version
	BuildDate() time.Time
	Type() LimePluginType
	Exports() map[string]interface{}
}

LimePlugin is a generic interface for lime plugins

type LimePluginType

type LimePluginType int

LimePluginType is the type of lime plugin

const (

	// GenericFileGenerator is a generic plugin that generates files
	GenericFileGenerator LimePluginType
	// CertificateGenerator is a plugin that generates certificates
	CertificateGenerator
	// CommandProxy is a plugin that acts as a proxy for executing commands
	CommandProxy
	// ConfigStore is a plugin that as as a configuration storage
	ConfigStore
)

func ParseLimePluginType

func ParseLimePluginType(v string) (LimePluginType, error)

ParseLimePluginType parses a LimePluginType

func (LimePluginType) String

func (t LimePluginType) String() string

Jump to