Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type LimePlugin ¶
type LimePlugin interface {
Name() string
Description() string
Version() *common.Version
BuildDate() time.Time
Type() LimePluginType
Exports() map[string]interface{}
}
LimePlugin is a generic interface for lime plugins
type LimePluginType ¶
type LimePluginType int
LimePluginType is the type of lime plugin
const ( // GenericFileGenerator is a generic plugin that generates files GenericFileGenerator LimePluginType // CertificateGenerator is a plugin that generates certificates CertificateGenerator // CommandProxy is a plugin that acts as a proxy for executing commands CommandProxy // ConfigStore is a plugin that as as a configuration storage ConfigStore )
func ParseLimePluginType ¶
func ParseLimePluginType(v string) (LimePluginType, error)
ParseLimePluginType parses a LimePluginType
func (LimePluginType) String ¶
func (t LimePluginType) String() string
Click to show internal directories.
Click to hide internal directories.